filename INF  "apstat.dat";

** Reads in ASCII file containing the data        **;
** Note y_j = 0 denotes good self assessment and  **;
** y_j = 1 denotes bad self assessment.           **;

** Gender : 1 if male                                **;
** age    : in years                                 **;
** treat  : treatment (1 if auranofin, 0 if placebo) **;

data temp;
  infile inf;
  input gender age trt  y1-y5;
  patient = _n_;  /* Creates patient ID's */
run;

%let y = y;
%let x = int time gender age treat;
%let z = distance;

data XY (keep=patient &y &x)  Z (keep = patient &z);
  set temp;
  int = 1; /* intercept */
  array y_[*]  y1-y5;
  array t_[*]  t1-t5 (0 1 5 9 13);

  /* Creates the design matrix for the mean model */ 
  /* as well as the response.                     */
  do j = 1 to 5;
    y = y_[j];
    if (y ^= .) then do
      y = ^y;           * model prob(good);
      time = t_[j];
      treat = trt * (j>2);
      output XY;
    end;
  end;

  /* Creates the design matrix for the association model. */
  do j = 1 to 4;
    if (y_[j] ^= .) then do k = (j+1) to 5;
      if (y_[k] ^= .) then do;
        distance = 1 / abs(t_[j]-t_[k]);
        output Z;
      end;
    end;
  end;

run;

** Create weight matrix      **; 
** Each cluster has weight 1 **;
data weight (keep=w);
  set temp;
  w=1;
run;


** Invokes the macro **;

%include "ORTHREScls.macro";

** Performs ALR using ORTH **;
%ORTHRESCLS(xydata=xy, yvar=&y, xvar=&x, id=patient, zdata=z, zvar=&z,  
         wdata=weight, wvar=w, maxiter=20, epsilon=0.0000001, estlamb = NO, 
         CLSOUT=clsout, obsout=obsout, monitor=no, IBETA=, IALPHA=);

quit; * Stops IML from continuing;

proc print data = clsout; title2 "clsout"; run;
proc print data = obsout; title2 "obsout"; run;
